@@ -8,20 +8,24 @@ from swap.common.logging import logger
 class UBLClient:
     def __init__(self):
         self.base_url = Settings.UBL_URL
-        self.id_token = os.getenv('SWAP_API_TOKEN')
+        self.api_key = os.getenv('SWAP_API_TOKEN')
 
     def url(self, path):
         return urljoin(self.base_url, path)
 
     def get(self, path=''):
+        logger.debug(f'Getting from UBL on path: {self.url(path)}')
+        params = {'api_key': self.api_key}
         joined_url = self.url(path)
-        response = requests.get(joined_url, headers={'id_token': self.id_token})
+        response = requests.get(joined_url, params=params)
 
         return response.text
 
     def post(self, path='', data={}):
         logger.debug(f'Posting to UBL on path: {self.url(path)}')
-        response = requests.post(self.url(path), json=data, headers={'id_token': self.id_token})
+        params = {'api_key': self.api_key}
+        joined_url = self.url(path)
+        response = requests.post(joined_url, json=data, params=params)
 
         if response.status_code != requests.codes.ok:
             raise Exception(f'UBL API call response not OK: {response.status_code}')
