@@ -185,7 +185,7 @@ class ProgressRequestCommand(Command):
                 service_chain_uuid=service_chain_uuid, chain_link=key
             )
 
-            result = state_machine.run()
+            result = state_machine.run(input)
             output[key] = result
 
         return output
